@@ -25,6 +25,7 @@
 #include "fdevent.h"
 #include "sys-socket.h"
 #include "splaytree.h"
+#include "etag.h"
 
 
 #if defined HAVE_LIBSSL && defined HAVE_OPENSSL_SSL_H
@@ -269,6 +270,9 @@ typedef struct {
 	unsigned short use_ipv6;
 	unsigned short is_ssl;
 	unsigned short allow_http11;
+	unsigned short etag_use_inode;
+	unsigned short etag_use_mtime;
+	unsigned short etag_use_size;
 	unsigned short force_lowercase_filenames; /* if the FS is case-insensitive, force all files to lower-case */
 	unsigned short max_request_size;
 
@@ -410,6 +414,8 @@ typedef struct {
 	SSL *ssl;
 	buffer *ssl_error_want_reuse_buffer;
 #endif
+	/* etag handling */
+	etag_flags_t etag_flags;
 } connection;
 
 typedef struct {
