@@ -1252,6 +1252,16 @@ connection *connection_accept(server *srv, server_socket *srv_socket) {
 	socklen_t cnt_len;
 	/* accept it and register the fd */
 
+	/**
+	 * check if we can still open a new connections
+	 *
+	 * see #1216
+	 */
+
+	if (srv->conns->used >= srv->max_conns) {
+		return NULL;
+	}
+
 	cnt_len = sizeof(cnt_addr);
 
 	if (-1 == (cnt = accept(srv_socket->fd, (struct sockaddr *) &cnt_addr, &cnt_len))) {
@@ -1265,6 +1275,9 @@ connection *connection_accept(server *srv, server_socket *srv_socket) {
 		case ECONNABORTED: /* this is a FreeBSD thingy */
 			/* we were stopped _after_ we had a connection */
 			break;
+		case EMFILE:
+			/* out of fds */
+			break;
 		default:
 			log_error_write(srv, __FILE__, __LINE__, "ssd", "accept failed:", strerror(errno), errno);
 		}
@@ -1432,6 +1445,7 @@ int connection_state_machine(server *srv, connection *con) {
 				} else if (con->in_error_handler) {
 					/* error-handler is back and has generated content */
 					/* if Status: was set, take it otherwise use 200 */
+					con->http_status = con->error_handler_saved_status;
 				}
 
 				if (con->http_status == 0) con->http_status = 200;
