@@ -25,6 +25,7 @@
 
 typedef struct {
 	array *exclude_ext;
+	unsigned short etags_used;
 } plugin_config;
 
 typedef struct {
@@ -82,6 +83,7 @@ SETDEFAULTS_FUNC(mod_staticfile_set_defaults) {
 
 	config_values_t cv[] = {
 		{ "static-file.exclude-extensions", NULL, T_CONFIG_ARRAY, T_CONFIG_SCOPE_CONNECTION },       /* 0 */
+		{ "static-file.etags",    NULL, T_CONFIG_BOOLEAN, T_CONFIG_SCOPE_CONNECTION }, /* 1 */
 		{ NULL,                         NULL, T_CONFIG_UNSET, T_CONFIG_SCOPE_UNSET }
 	};
 
@@ -94,8 +96,10 @@ SETDEFAULTS_FUNC(mod_staticfile_set_defaults) {
 
 		s = calloc(1, sizeof(plugin_config));
 		s->exclude_ext    = array_init();
+		s->etags_used     = 1;
 
 		cv[0].destination = s->exclude_ext;
+		cv[1].destination = &(s->etags_used);
 
 		p->config_storage[i] = s;
 
@@ -114,6 +118,7 @@ static int mod_staticfile_patch_connection(server *srv, connection *con, plugin_
 	plugin_config *s = p->config_storage[0];
 
 	PATCH(exclude_ext);
+	PATCH(etags_used);
 
 	/* skip the first, the global context */
 	for (i = 1; i < srv->config_context->used; i++) {
@@ -129,7 +134,9 @@ static int mod_staticfile_patch_connection(server *srv, connection *con, plugin_
 
 			if (buffer_is_equal_string(du->key, CONST_STR_LEN("static-file.exclude-extensions"))) {
 				PATCH(exclude_ext);
-			}
+			} else if (buffer_is_equal_string(du->key, CONST_STR_LEN("static-file.etags"))) {
+				PATCH(etags_used);
+			} 
 		}
 	}
 
@@ -347,6 +354,7 @@ URIHANDLER_FUNC(mod_staticfile_subrequest) {
 	stat_cache_entry *sce = NULL;
 	buffer *mtime;
 	data_string *ds;
+	int allow_caching = 1;
 
 	/* someone else has done a decision for us */
 	if (con->http_status != 0) return HANDLER_GO_ON;
@@ -428,31 +436,46 @@ URIHANDLER_FUNC(mod_staticfile_subrequest) {
 
 	if (NULL == array_get_element(con->response.headers, "Content-Type")) {
 		if (buffer_is_empty(sce->content_type)) {
+			/* we are setting application/octet-stream, but also announce that
+			 * this header field might change in the seconds few requests 
+			 *
+			 * This should fix the aggressive caching of FF and the script download
+			 * seen by the first installations
+			 */
 			response_header_overwrite(srv, con, CONST_STR_LEN("Content-Type"), CONST_STR_LEN("application/octet-stream"));
+
+			allow_caching = 0;
 		} else {
 			response_header_overwrite(srv, con, CONST_STR_LEN("Content-Type"), CONST_BUF_LEN(sce->content_type));
 		}
 	}
 
-	if (NULL == array_get_element(con->response.headers, "ETag")) {
-		/* generate e-tag */
-		etag_mutate(con->physical.etag, sce->etag);
-
-		response_header_overwrite(srv, con, CONST_STR_LEN("ETag"), CONST_BUF_LEN(con->physical.etag));
-	}
 	response_header_overwrite(srv, con, CONST_STR_LEN("Accept-Ranges"), CONST_STR_LEN("bytes"));
 
-	/* prepare header */
-	if (NULL == (ds = (data_string *)array_get_element(con->response.headers, "Last-Modified"))) {
-		mtime = strftime_cache_get(srv, sce->st.st_mtime);
-		response_header_overwrite(srv, con, CONST_STR_LEN("Last-Modified"), CONST_BUF_LEN(mtime));
-	} else {
-		mtime = ds->value;
+	if (allow_caching) {
+		if (p->conf.etags_used && con->etag_flags != 0 && !buffer_is_empty(sce->etag)) {
+			if (NULL == array_get_element(con->response.headers, "ETag")) {
+				/* generate e-tag */
+				etag_mutate(con->physical.etag, sce->etag);
+
+				response_header_overwrite(srv, con, CONST_STR_LEN("ETag"), CONST_BUF_LEN(con->physical.etag));
+			}
+		}
+
+		/* prepare header */
+		if (NULL == (ds = (data_string *)array_get_element(con->response.headers, "Last-Modified"))) {
+			mtime = strftime_cache_get(srv, sce->st.st_mtime);
+			response_header_overwrite(srv, con, CONST_STR_LEN("Last-Modified"), CONST_BUF_LEN(mtime));
+		} else {
+			mtime = ds->value;
+		}
+
+		if (HANDLER_FINISHED == http_response_handle_cachable(srv, con, mtime)) {
+			return HANDLER_FINISHED;
+		}
 	}
 
-	if (HANDLER_FINISHED == http_response_handle_cachable(srv, con, mtime)) {
-		return HANDLER_FINISHED;
-	} else if (con->request.http_range && con->conf.range_requests) {
+	if (con->request.http_range && con->conf.range_requests) {
 		int do_range_request = 1;
 		/* check if we have a conditional GET */
 
